You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by pb...@apache.org on 2012/10/10 00:02:22 UTC

svn commit: r1396372 - in /subversion/branches/auto-props-sdc/subversion: libsvn_client/add.c libsvn_client/client.h libsvn_client/commit.c tests/cmdline/autoprop_tests.py tests/cmdline/svntest/main.py

Author: pburba
Date: Tue Oct  9 22:02:21 2012
New Revision: 1396372

URL: http://svn.apache.org/viewvc?rev=1396372&view=rev
Log:
On the auto-props-sdc branch: After a bit more bikeshedding, we decided to
name the magic inheritable auto-prop property 'svn:inheritable-auto-props'.

See http://svn.haxx.se/dev/archive-2012-10/0102.shtml.

* subversion/include/svn_props.h
  (SVN_CONFIG_PROP_PREFIX): Redefine.

* subversion/libsvn_client/add.c
* subversion/libsvn_client/client.h
* subversion/libsvn_client/commit.c
* subversion/tests/cmdline/autoprop_tests.py
  Use the new property name in comments, no logic changes.

* subversion/tests/cmdline/svntest/main.py
  (SVN_CONFIG_AUTOPROPS): Redefine.

Modified:
    subversion/branches/auto-props-sdc/subversion/libsvn_client/add.c
    subversion/branches/auto-props-sdc/subversion/libsvn_client/client.h
    subversion/branches/auto-props-sdc/subversion/libsvn_client/commit.c
    subversion/branches/auto-props-sdc/subversion/tests/cmdline/autoprop_tests.py
    subversion/branches/auto-props-sdc/subversion/tests/cmdline/svntest/main.py

Modified: subversion/branches/auto-props-sdc/subversion/libsvn_client/add.c
URL: http://svn.apache.org/viewvc/subversion/branches/auto-props-sdc/subversion/libsvn_client/add.c?rev=1396372&r1=1396371&r2=1396372&view=diff
==============================================================================
--- subversion/branches/auto-props-sdc/subversion/libsvn_client/client.h (original)
+++ subversion/branches/auto-props-sdc/subversion/libsvn_client/client.h Tue Oct  9 22:02:21 2012
@@ -351,11 +351,11 @@ svn_error_t *svn_client__get_paths_auto_
   apr_pool_t *scratch_pool);
 
 /* Gather all auto-props from CTX->config (or none if auto-props are
-   disabled) and all svn:iprop-auto-props explicitly set on or inherited
+   disabled) and all svn:inheritable-auto-props explicitly set on or inherited
    by PATH_OR_URL.
 
    If PATH_OR_URL is an unversioned WC path then gather the
-   svn:iprop-auto-props inherited by PATH_OR_URL's nearest versioned
+   svn:inheritable-auto-props inherited by PATH_OR_URL's nearest versioned
    parent.
 
    If PATH_OR_URL is a URL ask for the properties @HEAD, if it is a WC
@@ -366,10 +366,10 @@ svn_error_t *svn_client__get_paths_auto_
    names to const char *property values.
 
    If a given property name exists for the same pattern in both the config
-   file and in an a svn:iprop-auto-props property, the latter overrides the
+   file and in an a svn:inheritable-auto-props property, the latter overrides the
    former.  If a given property name exists for the same pattern in two
-   different inherited svn:iprop-auto-props, then the closer path-wise
-   property overrides the more distant. svn:iprop-auto-props explicitly set
+   different inherited svn:inheritable-auto-props, then the closer path-wise
+   property overrides the more distant. svn:inheritable-auto-props explicitly set
    on PATH_OR_URL have the highest precedence and override inherited props
    and config file settings.
 

Modified: subversion/branches/auto-props-sdc/subversion/libsvn_client/commit.c
URL: http://svn.apache.org/viewvc/subversion/branches/auto-props-sdc/subversion/libsvn_client/commit.c?rev=1396372&r1=1396371&r2=1396372&view=diff
==============================================================================
--- subversion/branches/auto-props-sdc/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/branches/auto-props-sdc/subversion/tests/cmdline/svntest/main.py Tue Oct  9 22:02:21 2012
@@ -175,7 +175,7 @@ work_dir = "svn-test-work"
 SVN_PROP_MERGEINFO = "svn:mergeinfo"
 
 # Constant for the inheritabled auto-props property.
-SVN_CONFIG_AUTOPROPS = "svn:iprop-auto-props"
+SVN_CONFIG_AUTOPROPS = "svn:inheritable-auto-props"
 
 # Where we want all the repositories and working copies to live.
 # Each test will have its own!
--- subversion/branches/auto-props-sdc/subversion/libsvn_client/add.c (original)
+++ subversion/branches/auto-props-sdc/subversion/libsvn_client/add.c Tue Oct  9 22:02:21 2012
@@ -284,7 +284,7 @@ add_file(const char *local_abspath,
       apr_hash_t *file_autoprops;
 
       /* Get automatic properties */
       /* Grab the inherited svn:iprop-auto-props and config file
          auto-props for this file if we haven't already got them
          when iterating over the file's unversioned parents. */
       if (autoprops == NULL)
@@ -372,12 +372,12 @@ add_file(const char *local_abspath,
  * if necessary.
  *
  * If not NULL, *CONFIG_AUTOPROPS is a hash representing the config file and
  * svn:iprop-auto-props autoprops which apply to DIR_ABSPATH.  It maps
  * const char * file patterns to another hash which maps const char *
  * property names to const char *property values.  If *CONFIG_AUTOPROPS is
  * NULL and DIR_ABSPATH is unversioned, then this function will populate
  * *CONFIG_AUTOPROPS (allocated in RESULT_POOL) using DIR_ABSPATH's nearest
  * versioned parent to determine the svn:iprop-auto-props which DIR_ABSPATH
  * will inherit once added.
  *
  * If CTX->CANCEL_FUNC is non-null, call it with CTX->CANCEL_BATON to allow
@@ -426,7 +426,7 @@ add_dir_recursive(const char *dir_abspat
         }
     }
 
   /* Grab the inherited svn:iprop-auto-props and config file
      auto-props for the roots of any unversioned trees. */
   if (!entry_exists && *config_autoprops == NULL)
     {
@@ -500,7 +500,7 @@ add_dir_recursive(const char *dir_abspat
 }
 
 /* This structure is used as baton for collecting the config entries
-   in the auto-props section and any inherited svn:iprop-auto-props
+   in the auto-props section and any inherited svn:inheritable-auto-props
    properties.
 */
 typedef struct collect_auto_props_baton_t
@@ -665,7 +665,7 @@ svn_client__get_all_auto_props(apr_hash_
 
   /* Are "traditional" auto-props enabled?  If so grab them from the
     config.  This is our starting set auto-props, which may be overriden
-    by svn:iprop-auto-props. */
+    by svn:inheritable-auto-props. */
   SVN_ERR(svn_config_get_bool(cfg, &use_autoprops,
                               SVN_CONFIG_SECTION_MISCELLANY,
                               SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS, FALSE));
@@ -744,7 +744,7 @@ svn_client__get_all_auto_props(apr_hash_
           config_auto_prop_pattern = svn_stringbuf_create_empty(iterpool);
           config_auto_prop_val = svn_stringbuf_create_empty(iterpool);
 
           /* Parse svn:iprop-auto-props value. */
           while (*ch != '\0')
             {
               svn_stringbuf_setempty(config_auto_prop_pattern);
@@ -284,7 +284,7 @@ add_file(const char *local_abspath,
 
       /* Get automatic properties */
-      /* Grab the inherited svn:iprop-auto-props and config file
+      /* Grab the inherited svn:inheritable-auto-props and config file
          auto-props for this file if we haven't already got them
          when iterating over the file's unversioned parents. */
@@ -372,12 +372,12 @@ add_file(const char *local_abspath,
  *
  * If not NULL, *CONFIG_AUTOPROPS is a hash representing the config file and
- * svn:iprop-auto-props autoprops which apply to DIR_ABSPATH.  It maps
+ * svn:inheritable-auto-props autoprops which apply to DIR_ABSPATH.  It maps
  * const char * file patterns to another hash which maps const char *
  * property names to const char *property values.  If *CONFIG_AUTOPROPS is
@@ -372,12 +372,12 @@ add_file(const char *local_abspath,
  * NULL and DIR_ABSPATH is unversioned, then this function will populate
  * *CONFIG_AUTOPROPS (allocated in RESULT_POOL) using DIR_ABSPATH's nearest
- * versioned parent to determine the svn:iprop-auto-props which DIR_ABSPATH
+ * versioned parent to determine the svn:inheritable-auto-props which DIR_ABSPATH
  * will inherit once added.
  *
@@ -426,7 +426,7 @@ add_dir_recursive(const char *dir_abspat
     }
 
-  /* Grab the inherited svn:iprop-auto-props and config file
+  /* Grab the inherited svn:inheritable-auto-props and config file
      auto-props for the roots of any unversioned trees. */
   if (!entry_exists && *config_autoprops == NULL)
@@ -744,7 +744,7 @@ svn_client__get_all_auto_props(apr_hash_
           config_auto_prop_val = svn_stringbuf_create_empty(iterpool);
 
-          /* Parse svn:iprop-auto-props value. */
+          /* Parse svn:inheritable-auto-props value. */
           while (*ch != '\0')
             {

Modified: subversion/branches/auto-props-sdc/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/branches/auto-props-sdc/subversion/libsvn_client/client.h?rev=1396372&r1=1396371&r2=1396372&view=diff
==============================================================================
--- subversion/branches/auto-props-sdc/subversion/libsvn_client/commit.c (original)
+++ subversion/branches/auto-props-sdc/subversion/libsvn_client/commit.c Tue Oct  9 22:02:21 2012
@@ -77,7 +77,7 @@ typedef struct import_ctx_t
   svn_magic__cookie_t *magic_cookie;
 
   /* Collection of all possible configuration file dictated auto-props and
-     svn:iprop-auto-props.  A hash mapping const char * file patterns to a
+     svn:inheritable-auto-props.  A hash mapping const char * file patterns to a
      second hash which maps const char * property names to const char *
      property values.  Properties which don't have a value, e.g. svn:executable,
      simply map the property name to an empty string. */
@@ -599,9 +599,9 @@ import_dir(const svn_delta_editor_t *edi
  * EXCLUDES is a hash whose keys are absolute paths to exclude from
  * the import (values are unused).
  *
  * AUTOPROPS is hash of all config file autoprops and svn:iprop-auto-props
  * inherited by the import target, see the IMPORT_CTX member of the same
  * name.
  *
  * If NO_IGNORE is FALSE, don't import files or directories that match
  * ignore patterns.
@@ -981,7 +981,7 @@ svn_client_import5(const char *path,
                                     commit_baton, NULL, TRUE,
                                     scratch_pool));
 
   /* Get inherited svn:iprop-auto-props for the location we
      are importing to. */
   SVN_ERR(svn_client__get_all_auto_props(&autoprops, url, ctx,
                                          scratch_pool, iterpool));
@@ -599,9 +599,9 @@ import_dir(const svn_delta_editor_t *edi
  * the import (values are unused).
  *
- * AUTOPROPS is hash of all config file autoprops and svn:iprop-auto-props
- * inherited by the import target, see the IMPORT_CTX member of the same
- * name.
+ * AUTOPROPS is hash of all config file autoprops and
+ * svn:inheritable-auto-props inherited by the import target, see the
+ * IMPORT_CTX member of the same name.
  *
  * If NO_IGNORE is FALSE, don't import files or directories that match
@@ -981,7 +981,7 @@ svn_client_import5(const char *path,
                                     scratch_pool));
 
-  /* Get inherited svn:iprop-auto-props for the location we
+  /* Get inherited svn:inheritable-auto-props for the location we
      are importing to. */
   SVN_ERR(svn_client__get_all_auto_props(&autoprops, url, ctx,

Modified: subversion/branches/auto-props-sdc/subversion/tests/cmdline/autoprop_tests.py
URL: http://svn.apache.org/viewvc/subversion/branches/auto-props-sdc/subversion/tests/cmdline/autoprop_tests.py?rev=1396372&r1=1396371&r2=1396372&view=diff
==============================================================================
--- subversion/branches/auto-props-sdc/subversion/tests/cmdline/autoprop_tests.py (original)
+++ subversion/branches/auto-props-sdc/subversion/tests/cmdline/autoprop_tests.py Tue Oct  9 22:02:21 2012
@@ -385,7 +385,7 @@ def check_inheritable_autoprops(sbox, au
 #----------------------------------------------------------------------
 def inheritable_autoprops_test(sbox, cmd, cfgenable, clienable, subdir,
                                do_import_or_add=True):
   """configurable autoprops and svn:iprop-auto-props test.
 
      CMD is the subcommand to test: 'import' or 'add'
      if CFGENABLE is true, enable autoprops in the config file, else disable
@@ -438,7 +438,8 @@ def inheritable_autoprops_test(sbox, cmd
   else:
     files_wc_dir = wc_dir
 
   # Set differing svn:iprop-auto-props properties on various directories.
   sbox.simple_propset(SVN_CONFIG_AUTOPROPS,
                       '*.c = svn:eol-style=CRLF\n'
                       '*.bat = svn:executable',
@@ -589,10 +590,10 @@ def svn_config_autoprops_imp_yes_no(sbox
   inheritable_autoprops_test(sbox, 'import', 1, -1, '')
 
 #----------------------------------------------------------------------
 # Test svn:iprop-auto-props when 'svn add' targets an already versioned
 # target.
 def svn_config_autoprops_add_versioned_target(sbox):
-  "svn:iprop-auto-props and versioned target"
+  "svn:inheritable-auto-props and versioned target"
 
   config_dir = inheritable_autoprops_test(sbox, 'add', 1, 0, '', False)
 
@@ -385,7 +385,7 @@ def check_inheritable_autoprops(sbox, au
 def inheritable_autoprops_test(sbox, cmd, cfgenable, clienable, subdir,
                                do_import_or_add=True):
-  """configurable autoprops and svn:iprop-auto-props test.
+  """configurable autoprops and svn:inheritable-auto-props test.
 
      CMD is the subcommand to test: 'import' or 'add'
@@ -438,7 +438,8 @@ def inheritable_autoprops_test(sbox, cmd
     files_wc_dir = wc_dir
 
-  # Set differing svn:iprop-auto-props properties on various directories.
+  # Set differing svn:inheritable-auto-props properties on various
+  # directories.
   sbox.simple_propset(SVN_CONFIG_AUTOPROPS,
                       '*.c = svn:eol-style=CRLF\n'
@@ -589,10 +590,10 @@ def svn_config_autoprops_imp_yes_no(sbox
 
 #----------------------------------------------------------------------
-# Test svn:iprop-auto-props when 'svn add' targets an already versioned
+# Test svn:inheritable-auto-props when 'svn add' targets an already versioned
 # target.
 def svn_config_autoprops_add_versioned_target(sbox):

Modified: subversion/branches/auto-props-sdc/subversion/tests/cmdline/svntest/main.py
URL: http://svn.apache.org/viewvc/subversion/branches/auto-props-sdc/subversion/tests/cmdline/svntest/main.py?rev=1396372&r1=1396371&r2=1396372&view=diff
==============================================================================